import React, { forwardRef, useImperativeHandle, useState } from "react";
import "./index.scss";

interface IRefs {
  showPopup: Function;
  hidePopup: Function;
}
type IProps = {
  children: JSX.Element;
};

export default forwardRef<IRefs, IProps>(({ children }, ref) => {
  const [show, setShow] = useState<boolean>(false);
  const [animationOut, setAnimationOut] = useState<boolean>(false);

  const hidePopup = () => {
    setAnimationOut(true);
    setTimeout(() => {
      setShow(false);
      setAnimationOut(false);
    }, 200);
  };

  useImperativeHandle(
    ref,
    () => {
      return {
        showPopup() {
          setShow(true);
        },
        hidePopup,
      };
    },
    []
  );

  return (
    <>
      {show ? (
        <div className="ljn_container">
          <div className="ljn_mask" onClick={hidePopup}></div>
          <div
            className={[
              "ljn_popup",
              animationOut ? "ljn_popup_out" : null,
            ].join(" ")}
          >
            {children}
          </div>
        </div>
      ) : null}
    </>
  );
});
